Computes the weighted location and scatter matrix estimators of the j-th mixture component , where the weights are calculated in the expectation-step.
weightedSestimator(
Y,
mu_init,
sigma_init,
max_iterFP = 1,
weights,
fixed_alpha
)A matrix of size n x p.
The previously computed center: an numerical array of length p.
The previously computed scatter matrix: an array of numeric values p x p
the maximum number of fixed point iterations used for the algorithm, defaults to 1
The weights that contain the probability membership of each observation (related to the overall mixture components)
the fixed alpha value for the corresponding mixture component
A list including the estimated K centers and labels for the observations list(cov=matrixSigma,covAux1=covAux1,mu=muk,s=sk)
cov:the computed weithted scatter matrix
mu: the computed weithted center
s: the weighted scale factor s.